"""Portfolio Builder for constructing portfolios from strategy selections.

This module provides the PortfolioBuilder class for building portfolios
with a fluent interface.
"""

from .portfolio_builder import PortfolioBuilder

__all__ = ["PortfolioBuilder"]
